
"""
Tokopedia API Wrapper
~~~~~~~~~~~~~~~~~~~
A basic wrapper for the Tokopedia GraphQL API.
:copyright: (c) 2022-present munawariz
:license: MIT, see LICENSE for more details.
"""

__title__ = 'tokopedia-wrapper'
__author__ = 'munawariz'
__license__ = 'MIT'
__copyright__ = 'Copyright 2023-present munawariz'
__version__ = '0.2'